@@ -16,7 +16,6 @@
 
 #include "addlocationmodel.h"
 #include "kclockformat.h"
-#include "settingsmodel.h"
 #include "utilmodel.h"
 
 const QString TZ_CFG_GROUP = QStringLiteral("Timezones");
@@ -138,3 +137,5 @@ QHash<int, QByteArray> SavedLocationsModel::roleNames() const
 {
     return {{NameRole, "name"}, {TimeStringRole, "timeString"}, {RelativeTimeRole, "relativeTime"}, {CityRole, "city"}, {IdRole, "id"}};
 }
+
+#include "moc_savedlocationsmodel.cpp"
